# DerogationReplication.R

#
# Replication Data for
# "Emergency and Escape: Explaining Derogations from Human Rights Treaties" 
# Authors: Emilie M. Hafner-Burton, Larry R. Helfer, and Christopher J. Fariss 
#

# Note that because of a change to two of the packages (gee and Zelig) used in the original analysis the 3rd order termporal polynomial term cause the model to generate predicted probabilities close to 1 and therefore generated an error. Removing the 3rd ordered temporal polynomial term allows the models to be estimated without error and without change to the substantive results. Those interested in estimating the models in this alternative (DerogationReplicationAlternative.R) file must download the 1.0-7 version of the geepack package and the 3.4-8 version of the Zelig package

# remove objects from R workspace
rm(list = ls())

# load libraries
library(plotrix);library(Zelig);library(Amelia);library(survival);library(MatchIt);library(apsrtable); library(gee)

# load data
load("DerogationYearCount.Rdata")
load("imputations.RData")
load("imputationsFULL.RData")
load("imputationsSUB.RData")
load("dhm_data_spell1.Rdata")
load("dhm_data_spell2.Rdata")
load("dhm_data_spell3.Rdata")
load("dhm_data_spell4.Rdata")
load("dhm_data_spell5.Rdata")

# generate Figure 1
barplot(DerogationYearCount, space=0, main="Figure 1. Number of Derogations in Force in Each Year, 1977-2007", ylab="Count", xlab="Year", yaxt="n",font=2,font.lab=2)
axis(side=2,at=c(0,10,20,30,40,50),las=2,font=2,font.lab=2)

# estimate models (results displayed in Table 2)
# stable democracy model
model.01 <- zelig(y ~ stable.democracy + civtot + log(populationvalues) + log(realpercapitaincomevalues) + t1 + t2 + t3, data=a.data$imputations, model="logit.gee", id="ccode", robust=TRUE)
summary(model.01)

# strong court model
model.01 <- zelig(y ~ courtexec + civtot + log(populationvalues) + log(realpercapitaincomevalues) + t1 + t2 + t3, data=a.data$imputations, model="logit.gee", id="ccode", robust=TRUE)
summary(model.01)

# treaty ratification model
model.01 <- zelig(y ~ treaty.rat.avg + civtot + log(populationvalues) + log(realpercapitaincomevalues) + t1 + t2 + t3, data=a.data$imputations, model="logit.gee", id="ccode", robust=TRUE)
summary(model.01)

# democratization model
model.01 <- zelig(y ~ democratization + civtot + log(populationvalues) + log(realpercapitaincomevalues) + t1 + t2 + t3, data=a.data$imputations, model="logit.gee", id="ccode", robust=TRUE)
summary(model.01)

# foreign aid model
model.01 <- zelig(y ~ log(totalaid+1) + civtot + log(populationvalues) + log(realpercapitaincomevalues) + t1 + t2 + t3, data=a.data$imputations, model="logit.gee", id="ccode", robust=TRUE)
summary(model.01)

# trade model
model.01 <- zelig(y ~ log(trade+1) + civtot + log(populationvalues) + log(realpercapitaincomevalues) + t1 + t2 + t3, data=a.data$imputations, model="logit.gee", id="ccode", robust=TRUE)
summary(model.01)

# stable democracy model
model.01 <- zelig(y ~ stable.democracy + courtexec  + treaty.rat.avg + democratization + log(totalaid+1) + log(trade+1) + civtot + log(populationvalues) + log(realpercapitaincomevalues) + t1 + t2, data=a.data$imputations, model="logit.gee", id="ccode", robust=TRUE)
summary(model.01)


# estiamte model (results displayed in Table 3)
model.01 <- zelig(y~d0c0+d0c1+d1c0+civtot+log(populationvalues)+log(realpercapitaincomevalues)+t1+t2, data=a.data$imputations, model="logit.gee", id="ccode", robust=TRUE); summary(model.01)

# create mats to save simulated values for Figure 2
mm1 <- sd1 <- matrix(NA, nrow=1, ncol=4)

# simulated predited probabilites for states that have not-strong Democracy AND not-strong Court
x.out <- setx(model.01, d0c0=1, d1c0=0, d0c1=0, t1=0, t2=0)
s.out <- sim(model.01,x=x.out)
mean(s.out$qi$ev)
s1 <- s.out$qi$ev
quantile(s.out$qi$ev)
c1.1 <- quantile(s.out$qi$ev, c(.025, .975))
mm1[1,1] <- mean(s.out$qi$ev)
sd1[1,1] <- sd(s.out$qi$ev)
dd1.1 <- density(s.out$qi$ev)

# simulated predited probabilites for states that have not-strong Democracy AND strong Court
x.out <- setx(model.01,  d0c0=0, d1c0=0, d0c1=1, t1=0, t2=0)
s.out <- sim(model.01,x=x.out)
mean(s.out$qi$ev)
s2 <- s.out$qi$ev
quantile(s.out$qi$ev)
c1.2 <- quantile(s.out$qi$ev, c(.025, .975))
mm1[1,2] <- mean(s.out$qi$ev)
sd1[1,2] <- sd(s.out$qi$ev)
dd1.2 <- density(s.out$qi$ev)

# simulated predited probabilites for states that have strong Democracy AND not-strong Court
x.out <- setx(model.01,  d0c0=0, d1c0=1, d0c1=0, t1=0, t2=0)
s.out <- sim(model.01,x=x.out)
mean(s.out$qi$ev)
s3 <- s.out$qi$ev
quantile(s.out$qi$ev)
c1.3 <- quantile(s.out$qi$ev, c(.025, .975))
mm1[1,3] <- mean(s.out$qi$ev)
sd1[1,3] <- sd(s.out$qi$ev)
dd1.3 <- density(s.out$qi$ev)

# simulated predited probabilites for states that have strong Democracy AND strong Court
x.out <- setx(model.01,  d0c0=0, d1c0=0, d0c1=0, t1=0, t2=0)
s.out <- sim(model.01,x=x.out)
mean(s.out$qi$ev)
s4 <- s.out$qi$ev
quantile(s.out$qi$ev)
c1.4 <- quantile(s.out$qi$ev, c(.025, .975))
mm1[1,4] <- mean(s.out$qi$ev)
sd1[1,4] <- sd(s.out$qi$ev)
dd1.4 <- density(s.out$qi$ev)

# generate plot (Figure 2)
# note that the simulated data take slightly different values each
# time the code is run so the densities in the plot are also slightly different
plot(dd1.4,  ylim=c(0,14), xlim=c(0,1), lwd=4 , col=1, lty=1, xlab="Predicted Probaility", ylab="Kernal Density (simulated draws=1000)", main="Figure 2. Probability of Treaty Derogation", cex.main=1, cex.lab=1, font=2,font.lab=2, font.axis=1, yaxt="n")
lines(dd1.3, xlim=c(0,1), lwd=1.5, col=grey(.20), lty=2)
lines(dd1.2, xlim=c(0,1), lwd=1.5, col=grey(.40), lty=3)
lines(dd1.1, xlim=c(0,1), lwd=1.5, col=grey(.60), lty=4)
text("Stable Democracy \n and Strong Court",x=(mean(dd1.4$x)-.15), y=max(dd1.4$y), font=2, col=1)
text("Stable Democracy \n and Weak Court",x=(mean(dd1.3$x)-.15), y=max(dd1.3$y), font=2, col=grey(.20))
text("Not-Stable Democracy \n and Strong Court",x=(mean(dd1.2$x)-.30), y=max(dd1.2$y), font=2, col=grey(.40))
text("Not-Stable Democracy \n and Weak Court",x=(mean(dd1.1$x)-.15), y=max(dd1.1$y)+1, font=2, col=grey(.60))
axis(side=2, at=c(0,2,4,6,8,10,12,14),las=2,font=2,font.lab=2)

# models for Table 4
# by derogation country spell
model.01 <- zelig(proprights ~ proprights_lag1 + stable.democracy + courtexec + democratization + treaty.rat.avg + log(totalaid+1) + log(trade+1) + civtot + log(populationvalues) + log(realpercapitaincomevalues), data=d.data$imputations, model="normal.gee", id="newcode", robust=TRUE)
summary(model.01)
model.01 <- zelig(proptime ~ proptime_lag1 + stable.democracy + courtexec + democratization + treaty.rat.avg + log(totalaid+1) + log(trade+1) + civtot + log(populationvalues) + log(realpercapitaincomevalues), data=d.data$imputations, model="normal.gee", id="ccode",  robust=TRUE)
summary(model.01)

# alternative lag structure 
model.01 <- zelig(proprights ~ proprights_lag1 + total_lag1 + stable.democracy + courtexec + democratization + treaty.rat.avg + log(totalaid+1) + log(trade+1) + civtot + log(populationvalues) + log(realpercapitaincomevalues), data=d.data$imputations, model="normal.gee", id="newcode", robust=TRUE)
summary(model.01)
model.01 <- zelig(proptime ~ proptime_lag1 + total_lag1 + stable.democracy + courtexec + democratization + treaty.rat.avg + log(totalaid+1) + log(trade+1) + civtot + log(populationvalues) + log(realpercapitaincomevalues), data=d.data$imputations, model="normal.gee", id="newcode",  robust=TRUE)
summary(model.01)

# alternative cluster (by derogation country spell)
model.01 <- zelig(proprights ~ proprights_lag1 + stable.democracy + courtexec + democratization + treaty.rat.avg + log(totalaid+1) + log(trade+1) + civtot + log(populationvalues) + log(realpercapitaincomevalues), data=d.data$imputations, model="normal.gee", id="ccode", robust=TRUE)
summary(model.01)
model.01 <- zelig(proptime ~ proptime_lag1 + stable.democracy + courtexec + democratization + treaty.rat.avg + log(totalaid+1) + log(trade+1) + civtot + log(populationvalues) + log(realpercapitaincomevalues), data=d.data$imputations, model="normal.gee", id="ccode",  robust=TRUE)
summary(model.01)

# alternative lag structure and alternative cluster (by country code)
model.01 <- zelig(proprights ~ proprights_lag1 + total_lag1 + stable.democracy + courtexec + democratization + treaty.rat.avg + log(totalaid+1) + log(trade+1) + civtot + log(populationvalues) + log(realpercapitaincomevalues), data=d.data$imputations, model="normal.gee", id="ccode", robust=TRUE)
summary(model.01)
model.01 <- zelig(proptime ~ proptime_lag1 + total_lag1 + stable.democracy + courtexec + democratization + treaty.rat.avg + log(totalaid+1) + log(trade+1) + civtot + log(populationvalues) + log(realpercapitaincomevalues), data=d.data$imputations, model="normal.gee", id="ccode",  robust=TRUE)
summary(model.01)

# generate plot (Firgure 3)
# create labels for each of 5 plot regions
figure_title <- "Figure 3: Hazard Model of Duration of Derogation Period as a function of Political Violence"
title_all <- "All Derogating States"
title_dem <-"Derogating Stable Democracies"
title_not_dem <-"Derogating States with Strong Courts"
title_court <-"Derogating States other \n than Stable Democracies"
title_not_court <-"Derogating States \n without Strong Courts"
y_label <- "Predicted Probability of Duration of Derogation Period"
x_label <-"Time in Years"

# the models below are generated with a 3 year minimum gap year between new derogation spells
# see the additional models further below, which are also discussed in the appendix

# All Derogating States
par(mfrow=c(1,1), mar=c(25,12,3,10), new=FALSE)
f <- survfit(Surv(spell_time3, right_censor_time3) ~ violence_dummy_2, data=subset(dhm_data_spell3, strong_court>=0))
plot(f, xlim=c(0,22), col=c(4,2), lty=c(1,5), lwd=2, xlab="", ylab="", main="", font=2, font.lab=2, cex.lab=1.0, cex.main=1.0, cex.axis=0.75,yaxt="n"); legend("topright", legend=c("High Political Violence", "Low Political Violence"), lty=c(5,1), col=c(2,4), lwd=c(2,2), cex=0.75)
mtext(title_all, side=3, font=2, cex=0.90)
axis(side=2, at=c(0,.2,.4,.6,.8,1),las=2,font=2,font.lab=2,cex.axis=0.75)

# Derogating Stable Democracies
par(mfrow=c(1,1), mar=c(15,4,13,18), new=TRUE)
f <- survfit(Surv(spell_time3, right_censor_time3) ~ violence_dummy_2, data=subset(dhm_data_spell3, stable.democracy==1))
plot(f, xlim=c(0,22), col=c(4,2), lty=c(1,5), lwd=2, xlab="", ylab="", main="", font=2, font.lab=2, cex.lab=1.00, cex.main=1.00, cex.axis=0.75,yaxt="n"); #legend("topright", legend=c("High Political Violence", "Low Political Violence"), lty=c(5,1), col=c(2,4), lwd=c(2,2))
mtext(title_dem, side=3, font=2, cex=0.90)
axis(side=2, at=c(0,.2,.4,.6,.8,1),las=2,font=2,font.lab=2,cex.axis=0.75)

# Derogating States with Strong Courts
par(mfrow=c(1,1), mar=c(15,19,13,3), new=TRUE)
f <- survfit(Surv(spell_time3, right_censor_time3) ~ violence_dummy_2, data=subset(dhm_data_spell3,  strong_court==1))
plot(f, xlim=c(0,22), col=c(4,2), lty=c(1,5), lwd=2, xlab="", ylab="", main="", font=2, font.lab=2, cex.lab=1.00, cex.main=1.00, cex.axis=0.75,yaxt="n"); #legend("topright", legend=c("High Political Violence", "Low Political Violence"), lty=c(5,1), col=c(2,4), lwd=c(2,2))
mtext(title_not_dem, side=3, font=2, cex=0.90)
axis(side=2, at=c(0,.2,.4,.6,.8,1),las=2,font=2,font.lab=2,cex.axis=0.75)

# Derogating States without Strong Courts
par(mfrow=c(1,1), mar=c(4,4,24,18), new=TRUE)
f <- survfit(Surv(spell_time3, right_censor_time3) ~ violence_dummy_2, data=subset(dhm_data_spell3, stable.democracy==0))
plot(f, xlim=c(0,22), col=c(4,2), lty=c(1,5), lwd=2, xlab="", ylab="", main="", font=2, font.lab=2, cex.lab=1.00, cex.main=1.00, cex.axis=0.75,yaxt="n"); #legend("topright", legend=c("High Political Violence", "Low Political Violence"), lty=c(5,1), col=c(2,4), lwd=c(2,2))
mtext(title_court, side=3, font=2, cex=0.90)
axis(side=2, at=c(0,.2,.4,.6,.8,1),las=2,font=2,font.lab=2,cex.axis=0.75)

# Derogating States without Strong Courts
par(mfrow=c(1,1), mar=c(4,19,24,3), new=TRUE)
f <- survfit(Surv(spell_time3, right_censor_time3) ~ violence_dummy_2, data=subset(dhm_data_spell3,  strong_court==0))
plot(f, xlim=c(0,22), col=c(4,2), lty=c(1,5), lwd=2, xlab="", ylab="", main="", font=2, font.lab=2, cex.lab=1.00, cex.main=1.00, cex.axis=0.75,yaxt="n"); #legend("topright", legend=c("High Political Violence", "Low Political Violence"), lty=c(5,1), col=c(2,4), lwd=c(2,2))
mtext(title_not_court, side=3, font=2, cex=0.90)
axis(side=2, at=c(0,.2,.4,.6,.8,1),las=2,font=2,font.lab=2,cex.axis=0.75)

# add labels to the outer plot region
par(mfrow=c(1,1), mar=c(1,1,1,1), new=TRUE)
plot(0,0, type="n", axes=F, xlab="", ylab="")
mtext(figure_title, side=3, font=2, cex=0.95)
mtext(y_label, side=2, font=2, cex=0.95)
mtext(x_label, side=1, font=2, cex=0.95)
par(mar=c(5,4,4,4))

# estimate model for Table 9 in the appendix
# ordinal political violence variable
# model with 1 year minimum gap year between derogation spells
f1 <- coxph(Surv(spell_time1, right_censor_time1) ~ stable.democracy + strong_court + civtot+ log(populationvalues+1) + log(realpercapitaincomevalues+1) + cluster(ccode), data=subset(dhm_data_spell1), robust=TRUE)

# model with 2 year minimum gap year between derogation spells
f2 <- coxph(Surv(spell_time2, right_censor_time2) ~ stable.democracy + strong_court + civtot + log(populationvalues+1) + log(realpercapitaincomevalues+1) + cluster(ccode), data=subset(dhm_data_spell2), robust=TRUE)

# model with 3 year minimum gap year between derogation spells
f3 <- coxph(Surv(spell_time3, right_censor_time3) ~ stable.democracy + strong_court + civtot + log(populationvalues+1) + log(realpercapitaincomevalues+1) + cluster(ccode), data=subset(dhm_data_spell3), robust=TRUE)

# model with 4 year minimum gap year between derogation spells
f4 <- coxph(Surv(spell_time4, right_censor_time4) ~ stable.democracy + strong_court + civtot + log(populationvalues+1) + log(realpercapitaincomevalues+1) + cluster(ccode), data=subset(dhm_data_spell4), robust=TRUE)

# model with 5 year minimum gap year between derogation spells
f5 <- coxph(Surv(spell_time5, right_censor_time5) ~ stable.democracy + strong_court + civtot + log(populationvalues+1) + log(realpercapitaincomevalues+1) + cluster(ccode), data=subset(dhm_data_spell5), robust=TRUE)

# print results for appendix
apsrtable(f1, f2, f3, f4, f5, digits=3)

# estimate model for Table 10 in the appendix
# dichotomous political violence variable
# model with 1 year minimum gap year between derogation spells
f1 <- coxph(Surv(spell_time1, right_censor_time1) ~ stable.democracy + strong_court + violence_dummy_2 + log(populationvalues+1) + log(realpercapitaincomevalues+1) + cluster(ccode), data=subset(dhm_data_spell1), robust=TRUE)

# model with 2 year minimum gap year between derogation spells
f2 <- coxph(Surv(spell_time2, right_censor_time2) ~ stable.democracy + strong_court + violence_dummy_2 + log(populationvalues+1) + log(realpercapitaincomevalues+1) + cluster(ccode), data=subset(dhm_data_spell2), robust=TRUE)

# model with 3 year minimum gap year between derogation spells
f3 <- coxph(Surv(spell_time3, right_censor_time3) ~ stable.democracy + strong_court + violence_dummy_2 + log(populationvalues+1) + log(realpercapitaincomevalues+1) + cluster(ccode), data=subset(dhm_data_spell3), robust=TRUE)

# model with 4 year minimum gap year between derogation spells
f4 <- coxph(Surv(spell_time4, right_censor_time4) ~ stable.democracy + strong_court + violence_dummy_2 + log(populationvalues+1) + log(realpercapitaincomevalues+1) + cluster(ccode), data=subset(dhm_data_spell4), robust=TRUE)

# model with 5 year minimum gap year between derogation spells
f5 <- coxph(Surv(spell_time5, right_censor_time5) ~ stable.democracy + strong_court + violence_dummy_2 + log(populationvalues+1) + log(realpercapitaincomevalues+1) + cluster(ccode), data=subset(dhm_data_spell5), robust=TRUE)

# print results for appendix
apsrtable(f1, f2, f3, f4, f5, digits=3)

# estimate model for Table 16 in the appendix
# dichotomous political violence variable
# model with 1 year minimum gap year between derogation spells
f1 <- coxph(Surv(spell_time1, right_censor_time1) ~ civtot + log(populationvalues+1) + log(realpercapitaincomevalues+1) + cluster(ccode), data=subset(dhm_data_spell1, stable.democracy==1), robust=TRUE)

# model with 2 year minimum gap year between derogation spells
f2 <- coxph(Surv(spell_time2, right_censor_time2) ~ civtot + log(populationvalues+1) + log(realpercapitaincomevalues+1) + cluster(ccode), data=subset(dhm_data_spell2, stable.democracy==1), robust=TRUE)

# model with 3 year minimum gap year between derogation spells
f3 <- coxph(Surv(spell_time3, right_censor_time3) ~ civtot + log(populationvalues+1) + log(realpercapitaincomevalues+1) + cluster(ccode), data=subset(dhm_data_spell3, stable.democracy==1), robust=TRUE)

# model with 4 year minimum gap year between derogation spells
f4 <- coxph(Surv(spell_time4, right_censor_time4) ~ civtot + log(populationvalues+1) + log(realpercapitaincomevalues+1) + cluster(ccode), data=subset(dhm_data_spell4, stable.democracy==1), robust=TRUE)

# model with 5 year minimum gap year between derogation spells
f5 <- coxph(Surv(spell_time5, right_censor_time5) ~ civtot + log(populationvalues+1) + log(realpercapitaincomevalues+1) + cluster(ccode), data=subset(dhm_data_spell5, stable.democracy==1), robust=TRUE)

# print results for appendix
apsrtable(f1, f2, f3, f4, f5, digits=3)

# estimate model for Table 17 in the appendix
# dichotomous political violence variable
# model with 1 year minimum gap year between derogation spells
f1 <- coxph(Surv(spell_time1, right_censor_time1) ~ violence_dummy_2 + log(populationvalues+1) + log(realpercapitaincomevalues+1) + cluster(ccode), data=subset(dhm_data_spell1, stable.democracy==1), robust=TRUE)

# model with 2 year minimum gap year between derogation spells
f2 <- coxph(Surv(spell_time2, right_censor_time2) ~ violence_dummy_2 + log(populationvalues+1) + log(realpercapitaincomevalues+1) + cluster(ccode), data=subset(dhm_data_spell2, stable.democracy==1), robust=TRUE)

# model with 3 year minimum gap year between derogation spells
f3 <- coxph(Surv(spell_time3, right_censor_time3) ~ violence_dummy_2 + log(populationvalues+1) + log(realpercapitaincomevalues+1) + cluster(ccode), data=subset(dhm_data_spell3, stable.democracy==1), robust=TRUE)

# model with 4 year minimum gap year between derogation spells
f4 <- coxph(Surv(spell_time4, right_censor_time4) ~ violence_dummy_2 + log(populationvalues+1) + log(realpercapitaincomevalues+1) + cluster(ccode), data=subset(dhm_data_spell4, stable.democracy==1), robust=TRUE)

# model with 5 year minimum gap year between derogation spells
f5 <- coxph(Surv(spell_time5, right_censor_time5) ~ violence_dummy_2 + log(populationvalues+1) + log(realpercapitaincomevalues+1) + cluster(ccode), data=subset(dhm_data_spell5, stable.democracy==1), robust=TRUE)

# print results for appendix
apsrtable(f1, f2, f3, f4, f5, digits=3)
 

# generate matched sample for treatment effects model using the nearest neighbor matching algorithim
m.out <- matchit(d1c1 ~ civtot + log(populationvalues) + log(realpercapitaincomevalues) + t1 + t2 + t3, data=as.data.frame(a.data$imputations), method = "nearest")
summary(m.out)
plot(m.out,  type = "jitter", interactive = FALSE)
plot(m.out,  type = "hist", col="grey70"); par(mfrow=c(1,1))

# estimate treatment effects model (displayed in Table 7 in the appendix)
model.01 <- zelig(y ~ d1c1 + civtot + log(populationvalues) + log(realpercapitaincomevalues) + t1 + t2 + t3, data=match.data(m.out), model="logit.gee", id="ccode", robust=TRUE)
summary(model.01)$coefficients

# generate matched sample for treatment effects model using the optimal matching algorithim
m.out <- matchit(d1c1 ~ civtot + log(populationvalues) + log(realpercapitaincomevalues) + t1 + t2 + t3, data=as.data.frame(a.data$imputations), method = "optimal")
summary(m.out)
plot(m.out,  type = "jitter", interactive = FALSE)
plot(m.out,  type = "hist", col="grey70"); par(mfrow=c(1,1))

# estimate treatment effects model (very similar results to those displayed in Table 11 in the appendix)
model.01 <- zelig(y ~ d1c1 + civtot + log(populationvalues) + log(realpercapitaincomevalues) + t1 + t2 + t3, data=match.data(m.out), model="logit.gee", id="ccode", robust=TRUE)
summary(model.01)$coefficients


# alternative variables for political violence (displated in Table 12 in the appendix)
model.01 <- zelig(y ~ stable.democracy + courtexec + protest + rebellion + violent.rebellion + civil.war + armed.conflict + log(populationvalues) + log(realpercapitaincomevalues) + t1 + t2 + t3, data=a.data$imputations, model="logit.gee", id="ccode", robust=TRUE)
summary(model.01)

model.01 <- zelig(y ~ stable.democracy + courtexec + civtot + I(civtot^2) + log(populationvalues) + log(realpercapitaincomevalues) + t1 + t2 + t3, data=a.data$imputations, model="logit.gee", id="ccode", robust=TRUE)
summary(model.01)

#cold war dummy variable (displayed in Table 19 in the appendix)
model.01 <- zelig(y ~ stable.democracy + courtexec + civtot + id5 + log(populationvalues) + log(realpercapitaincomevalues) + t1 + t2 + t3, data=a.data$imputations, model="logit.gee", id="ccode", robust=TRUE)
summary(model.01)

# descriptive statistics for model variables (N=1193) in Appendix Table 25
a.descriptive <- matrix(NA, nrow=13, ncol=4)
d <- matrix(NA, nrow=10, ncol=4)
for(i in 1:10){
d[i,1]<-mean(a.data$imputations[[i]]$stable.democracy); 
d[i,2]<-sd(a.data$imputations[[i]]$stable.democracy); 
d[i,3]<-min(a.data$imputations[[i]]$stable.democracy); 
d[i,4]<-max(a.data$imputations[[i]]$stable.democracy) 
}
k <- 1
a.descriptive[k,1] <- mean(d[,1])
a.descriptive[k,2] <- mean(d[,2])
a.descriptive[k,3] <- mean(d[,3])
a.descriptive[k,4] <- mean(d[,4])

d<-matrix(NA, nrow=10, ncol=4)
for(i in 1:10){
d[i,1]<-mean(a.data$imputations[[i]]$courtexec); 
d[i,2]<-sd(a.data$imputations[[i]]$courtexec); 
d[i,3]<-min(a.data$imputations[[i]]$courtexec); 
d[i,4]<-max(a.data$imputations[[i]]$courtexec) 
}
k <- 2
a.descriptive[k,1] <- mean(d[,1])
a.descriptive[k,2] <- mean(d[,2])
a.descriptive[k,3] <- mean(d[,3])
a.descriptive[k,4] <- mean(d[,4])

d<-matrix(NA, nrow=10, ncol=4)
for(i in 1:10){
d[i,1]<-mean(a.data$imputations[[i]]$d1c1); 
d[i,2]<-sd(a.data$imputations[[i]]$d1c1); 
d[i,3]<-min(a.data$imputations[[i]]$d1c1); 
d[i,4]<-max(a.data$imputations[[i]]$d1c1) 
}
k <- 3
a.descriptive[k,1] <- mean(d[,1])
a.descriptive[k,2] <- mean(d[,2])
a.descriptive[k,3] <- mean(d[,3])
a.descriptive[k,4] <- mean(d[,4])


d<-matrix(NA, nrow=10, ncol=4)
for(i in 1:10){
d[i,1]<-mean(a.data$imputations[[i]]$d1c0); 
d[i,2]<-sd(a.data$imputations[[i]]$d1c0); 
d[i,3]<-min(a.data$imputations[[i]]$d1c0); 
d[i,4]<-max(a.data$imputations[[i]]$d1c0) 
}
k <- 4
a.descriptive[k,1] <- mean(d[,1])
a.descriptive[k,2] <- mean(d[,2])
a.descriptive[k,3] <- mean(d[,3])
a.descriptive[k,4] <- mean(d[,4])

d<-matrix(NA, nrow=10, ncol=4)
for(i in 1:10){
d[i,1]<-mean(a.data$imputations[[i]]$d0c1); 
d[i,2]<-sd(a.data$imputations[[i]]$d0c1); 
d[i,3]<-min(a.data$imputations[[i]]$d0c1); 
d[i,4]<-max(a.data$imputations[[i]]$d0c1) 
}
k <- 5
a.descriptive[k,1] <- mean(d[,1])
a.descriptive[k,2] <- mean(d[,2])
a.descriptive[k,3] <- mean(d[,3])
a.descriptive[k,4] <- mean(d[,4])

d<-matrix(NA, nrow=10, ncol=4)
for(i in 1:10){
d[i,1]<-mean(a.data$imputations[[i]]$d0c0); 
d[i,2]<-sd(a.data$imputations[[i]]$d0c0); 
d[i,3]<-min(a.data$imputations[[i]]$d0c0); 
d[i,4]<-max(a.data$imputations[[i]]$d0c0) 
}
k <- 6
a.descriptive[k,1] <- mean(d[,1])
a.descriptive[k,2] <- mean(d[,2])
a.descriptive[k,3] <- mean(d[,3])
a.descriptive[k,4] <- mean(d[,4])

d<-matrix(NA, nrow=10, ncol=4)
for(i in 1:10){
d[i,1]<-mean(a.data$imputations[[i]]$civtot); 
d[i,2]<-sd(a.data$imputations[[i]]$civtot); 
d[i,3]<-min(a.data$imputations[[i]]$civtot); 
d[i,4]<-max(a.data$imputations[[i]]$civtot) 
}
k <- 7
a.descriptive[k,1] <- mean(d[,1])
a.descriptive[k,2] <- mean(d[,2])
a.descriptive[k,3] <- mean(d[,3])
a.descriptive[k,4] <- mean(d[,4])

d<-matrix(NA, nrow=10, ncol=4)
for(i in 1:10){
d[i,1]<-mean(log(a.data$imputations[[i]]$populationvalues)); 
d[i,2]<-sd(log(a.data$imputations[[i]]$populationvalues)); 
d[i,3]<-min(log(a.data$imputations[[i]]$populationvalues)); 
d[i,4]<-max(log(a.data$imputations[[i]]$populationvalues)) 
}
k <- 8
a.descriptive[k,1] <- mean(d[,1])
a.descriptive[k,2] <- mean(d[,2])
a.descriptive[k,3] <- mean(d[,3])
a.descriptive[k,4] <- mean(d[,4])

d<-matrix(NA, nrow=10, ncol=4)
for(i in 1:10){
d[i,1]<-mean(log(a.data$imputations[[i]]$realpercapitaincomevalues)); 
d[i,2]<-sd(log(a.data$imputations[[i]]$realpercapitaincomevalues)); 
d[i,3]<-min(log(a.data$imputations[[i]]$realpercapitaincomevalues)); 
d[i,4]<-max(log(a.data$imputations[[i]]$realpercapitaincomevalues)) 
}
k <- 9
a.descriptive[k,1] <- mean(d[,1])
a.descriptive[k,2] <- mean(d[,2])
a.descriptive[k,3] <- mean(d[,3])
a.descriptive[k,4] <- mean(d[,4])

d<-matrix(NA, nrow=10, ncol=4)
for(i in 1:10){
d[i,1]<-mean(a.data$imputations[[i]]$treaty.rat.avg); 
d[i,2]<-sd(a.data$imputations[[i]]$treaty.rat.avg); 
d[i,3]<-min(a.data$imputations[[i]]$treaty.rat.avg); 
d[i,4]<-max(a.data$imputations[[i]]$treaty.rat.avg) 
}
k <- 10
a.descriptive[k,1] <- mean(d[,1])
a.descriptive[k,2] <- mean(d[,2])
a.descriptive[k,3] <- mean(d[,3])
a.descriptive[k,4] <- mean(d[,4])

d<-matrix(NA, nrow=10, ncol=4)
for(i in 1:10){
d[i,1]<-mean(a.data$imputations[[i]]$democratization); 
d[i,2]<-sd(a.data$imputations[[i]]$democratization); 
d[i,3]<-min(a.data$imputations[[i]]$democratization); 
d[i,4]<-max(a.data$imputations[[i]]$democratization) 
}
k <- 11
a.descriptive[k,1] <- mean(d[,1])
a.descriptive[k,2] <- mean(d[,2])
a.descriptive[k,3] <- mean(d[,3])
a.descriptive[k,4] <- mean(d[,4])

d<-matrix(NA, nrow=10, ncol=4)
for(i in 1:10){
d[i,1]<-mean(log(a.data$imputations[[i]]$totalaid+1)); 
d[i,2]<-sd(log(a.data$imputations[[i]]$totalaid+1)); 
d[i,3]<-min(log(a.data$imputations[[i]]$totalaid+1)); 
d[i,4]<-max(log(a.data$imputations[[i]]$totalaid+1)) 
}
k <- 12
a.descriptive[k,1] <- mean(d[,1])
a.descriptive[k,2] <- mean(d[,2])
a.descriptive[k,3] <- mean(d[,3])
a.descriptive[k,4] <- mean(d[,4])

d<-matrix(NA, nrow=10, ncol=4)
for(i in 1:10){
d[i,1]<-mean(log(a.data$imputations[[i]]$trade+1)); 
d[i,2]<-sd(log(a.data$imputations[[i]]$trade+1)); 
d[i,3]<-min(log(a.data$imputations[[i]]$trade+1)); 
d[i,4]<-max(log(a.data$imputations[[i]]$trade+1)) 
}
k <- 13
a.descriptive[k,1] <- mean(d[,1])
a.descriptive[k,2] <- mean(d[,2])
a.descriptive[k,3] <- mean(d[,3])
a.descriptive[k,4] <- mean(d[,4])

# create table of descriptive statistics
dd <- data.frame(a.descriptive, row.names=c("Stable Democracy", "Court", "Stable Democracy and Court", "Stable Democracy and Not Court", "Not Stable Democracy and Court",  "Not Stable Democracy and Not Court", "Political Violence", "ln(Population)", "ln(Income)", "Treaty", "Democratization", "ln(Aid+1)", "ln(Trade+1)"))
names(dd)[1:4] <- c("Mean", "Std. Dev.", "Min", "Max")
dd



# descriptive statistics for model variablss (n=5572) in Appendix Table 23
load("imputationsFULL.RData")

a.descriptive <- matrix(NA, nrow=13, ncol=4)
d <- matrix(NA, nrow=10, ncol=4)
for(i in 1:10){
d[i,1]<-mean(a.data.full$imputations[[i]]$stable.democracy); 
d[i,2]<-sd(a.data.full$imputations[[i]]$stable.democracy); 
d[i,3]<-min(a.data.full$imputations[[i]]$stable.democracy); 
d[i,4]<-max(a.data.full$imputations[[i]]$stable.democracy) 
}
k <- 1
a.descriptive[k,1] <- mean(d[,1])
a.descriptive[k,2] <- mean(d[,2])
a.descriptive[k,3] <- mean(d[,3])
a.descriptive[k,4] <- mean(d[,4])

d<-matrix(NA, nrow=10, ncol=4)
for(i in 1:10){
d[i,1]<-mean(a.data.full$imputations[[i]]$courtexec); 
d[i,2]<-sd(a.data.full$imputations[[i]]$courtexec); 
d[i,3]<-min(a.data.full$imputations[[i]]$courtexec); 
d[i,4]<-max(a.data.full$imputations[[i]]$courtexec) 
}
k <- 2
a.descriptive[k,1] <- mean(d[,1])
a.descriptive[k,2] <- mean(d[,2])
a.descriptive[k,3] <- mean(d[,3])
a.descriptive[k,4] <- mean(d[,4])

d<-matrix(NA, nrow=10, ncol=4)
for(i in 1:10){
d[i,1]<-mean(a.data.full$imputations[[i]]$d1c1); 
d[i,2]<-sd(a.data.full$imputations[[i]]$d1c1); 
d[i,3]<-min(a.data.full$imputations[[i]]$d1c1); 
d[i,4]<-max(a.data.full$imputations[[i]]$d1c1) 
}
k <- 3
a.descriptive[k,1] <- mean(d[,1])
a.descriptive[k,2] <- mean(d[,2])
a.descriptive[k,3] <- mean(d[,3])
a.descriptive[k,4] <- mean(d[,4])


d<-matrix(NA, nrow=10, ncol=4)
for(i in 1:10){
d[i,1]<-mean(a.data.full$imputations[[i]]$d1c0); 
d[i,2]<-sd(a.data.full$imputations[[i]]$d1c0); 
d[i,3]<-min(a.data.full$imputations[[i]]$d1c0); 
d[i,4]<-max(a.data.full$imputations[[i]]$d1c0) 
}
k <- 4
a.descriptive[k,1] <- mean(d[,1])
a.descriptive[k,2] <- mean(d[,2])
a.descriptive[k,3] <- mean(d[,3])
a.descriptive[k,4] <- mean(d[,4])

d<-matrix(NA, nrow=10, ncol=4)
for(i in 1:10){
d[i,1]<-mean(a.data.full$imputations[[i]]$d0c1); 
d[i,2]<-sd(a.data.full$imputations[[i]]$d0c1); 
d[i,3]<-min(a.data.full$imputations[[i]]$d0c1); 
d[i,4]<-max(a.data.full$imputations[[i]]$d0c1) 
}
k <- 5
a.descriptive[k,1] <- mean(d[,1])
a.descriptive[k,2] <- mean(d[,2])
a.descriptive[k,3] <- mean(d[,3])
a.descriptive[k,4] <- mean(d[,4])

d<-matrix(NA, nrow=10, ncol=4)
for(i in 1:10){
d[i,1]<-mean(a.data.full$imputations[[i]]$d0c0); 
d[i,2]<-sd(a.data.full$imputations[[i]]$d0c0); 
d[i,3]<-min(a.data.full$imputations[[i]]$d0c0); 
d[i,4]<-max(a.data.full$imputations[[i]]$d0c0) 
}
k <- 6
a.descriptive[k,1] <- mean(d[,1])
a.descriptive[k,2] <- mean(d[,2])
a.descriptive[k,3] <- mean(d[,3])
a.descriptive[k,4] <- mean(d[,4])

d<-matrix(NA, nrow=10, ncol=4)
for(i in 1:10){
d[i,1]<-mean(a.data.full$imputations[[i]]$civtot); 
d[i,2]<-sd(a.data.full$imputations[[i]]$civtot); 
d[i,3]<-min(a.data.full$imputations[[i]]$civtot); 
d[i,4]<-max(a.data.full$imputations[[i]]$civtot) 
}
k <- 7
a.descriptive[k,1] <- mean(d[,1])
a.descriptive[k,2] <- mean(d[,2])
a.descriptive[k,3] <- mean(d[,3])
a.descriptive[k,4] <- mean(d[,4])

d<-matrix(NA, nrow=10, ncol=4)
for(i in 1:10){
d[i,1]<-mean(log(a.data.full$imputations[[i]]$populationvalues)); 
d[i,2]<-sd(log(a.data.full$imputations[[i]]$populationvalues)); 
d[i,3]<-min(log(a.data.full$imputations[[i]]$populationvalues)); 
d[i,4]<-max(log(a.data.full$imputations[[i]]$populationvalues)) 
}
k <- 8
a.descriptive[k,1] <- mean(d[,1])
a.descriptive[k,2] <- mean(d[,2])
a.descriptive[k,3] <- mean(d[,3])
a.descriptive[k,4] <- mean(d[,4])

d<-matrix(NA, nrow=10, ncol=4)
for(i in 1:10){
d[i,1]<-mean(log(a.data.full$imputations[[i]]$realpercapitaincomevalues)); 
d[i,2]<-sd(log(a.data.full$imputations[[i]]$realpercapitaincomevalues)); 
d[i,3]<-min(log(a.data.full$imputations[[i]]$realpercapitaincomevalues)); 
d[i,4]<-max(log(a.data.full$imputations[[i]]$realpercapitaincomevalues)) 
}
k <- 9
a.descriptive[k,1] <- mean(d[,1])
a.descriptive[k,2] <- mean(d[,2])
a.descriptive[k,3] <- mean(d[,3])
a.descriptive[k,4] <- mean(d[,4])

d<-matrix(NA, nrow=10, ncol=4)
for(i in 1:10){
d[i,1]<-mean(a.data.full$imputations[[i]]$treaty.rat.avg); 
d[i,2]<-sd(a.data.full$imputations[[i]]$treaty.rat.avg); 
d[i,3]<-min(a.data.full$imputations[[i]]$treaty.rat.avg); 
d[i,4]<-max(a.data.full$imputations[[i]]$treaty.rat.avg) 
}
k <- 10
a.descriptive[k,1] <- mean(d[,1])
a.descriptive[k,2] <- mean(d[,2])
a.descriptive[k,3] <- mean(d[,3])
a.descriptive[k,4] <- mean(d[,4])

d<-matrix(NA, nrow=10, ncol=4)
for(i in 1:10){
d[i,1]<-mean(a.data.full$imputations[[i]]$democratization); 
d[i,2]<-sd(a.data.full$imputations[[i]]$democratization); 
d[i,3]<-min(a.data.full$imputations[[i]]$democratization); 
d[i,4]<-max(a.data.full$imputations[[i]]$democratization) 
}
k <- 11
a.descriptive[k,1] <- mean(d[,1])
a.descriptive[k,2] <- mean(d[,2])
a.descriptive[k,3] <- mean(d[,3])
a.descriptive[k,4] <- mean(d[,4])

d<-matrix(NA, nrow=10, ncol=4)
for(i in 1:10){
d[i,1]<-mean(log(a.data.full$imputations[[i]]$totalaid+1)); 
d[i,2]<-sd(log(a.data.full$imputations[[i]]$totalaid+1)); 
d[i,3]<-min(log(a.data.full$imputations[[i]]$totalaid+1)); 
d[i,4]<-max(log(a.data.full$imputations[[i]]$totalaid+1)) 
}
k <- 12
a.descriptive[k,1] <- mean(d[,1])
a.descriptive[k,2] <- mean(d[,2])
a.descriptive[k,3] <- mean(d[,3])
a.descriptive[k,4] <- mean(d[,4])

d<-matrix(NA, nrow=10, ncol=4)
for(i in 1:10){
d[i,1]<-mean(log(a.data.full$imputations[[i]]$trade+1)); 
d[i,2]<-sd(log(a.data.full$imputations[[i]]$trade+1)); 
d[i,3]<-min(log(a.data.full$imputations[[i]]$trade+1)); 
d[i,4]<-max(log(a.data.full$imputations[[i]]$trade+1)) 
}
k <- 13
a.descriptive[k,1] <- mean(d[,1])
a.descriptive[k,2] <- mean(d[,2])
a.descriptive[k,3] <- mean(d[,3])
a.descriptive[k,4] <- mean(d[,4])

# create table of descriptive statistics
dd <- data.frame(a.descriptive, row.names=c("Stable Democracy", "Court", "Stable Democracy and Court", "Stable Democracy and Not Court", "Not Stable Democracy and Court",  "Not Stable Democracy and Not Court", "Political Violence", "ln(Population)", "ln(Income)", "Treaty", "Democratization", "ln(Aid+1)", "ln(Trade+1)"))
names(dd)[1:4] <- c("Mean", "Std. Dev.", "Min", "Max")
dd

# genearte descriptive statistics in Table 22, 24, or 27
load("DerogationData.Rdata")
data <- pre.data # data for Table 22
#data <- subset(pre.data, id2==1) # uncomment for data for Table 24
#data <- subset(pre.data, y==1) # uncomment for data for Table 27

data$d0c0[!is.na(data$stable.democracy) & !is.na(data$courtexec)] <- 0
data$d1c0[!is.na(data$stable.democracy) & !is.na(data$courtexec)] <- 0
data$d0c1[!is.na(data$stable.democracy) & !is.na(data$courtexec)] <- 0
data$d1c1[!is.na(data$stable.democracy) &  !is.na(data$courtexec)] <- 0

data$d0c0[data$stable.democracy==0 & data$courtexec==0] <- 1
data$d1c0[data$stable.democracy==1 & data$courtexec==0] <- 1
data$d0c1[data$stable.democracy==0 & data$courtexec==1] <- 1
data$d1c1[data$stable.democracy==1 & data$courtexec==1] <- 1

a.descriptive <- matrix(NA, nrow=13, ncol=4)
d <- matrix(NA, nrow=1, ncol=4)
d[1,1]<-mean(na.omit(data$stable.democracy)); 
d[1,2]<-sd(na.omit(data$stable.democracy)); 
d[1,3]<-min(na.omit(data$stable.democracy)); 
d[1,4]<-max(na.omit(data$stable.democracy)) 
k <- 1
a.descriptive[k,1] <- mean(d[,1])
a.descriptive[k,2] <- mean(d[,2])
a.descriptive[k,3] <- mean(d[,3])
a.descriptive[k,4] <- mean(d[,4])

d<-matrix(NA, nrow=1, ncol=4)
d[1,1]<-mean(na.omit(data$courtexec)); 
d[1,2]<-sd(na.omit(data$courtexec)); 
d[1,3]<-min(na.omit(data$courtexec)); 
d[1,4]<-max(na.omit(data$courtexec)) 
k <- 2
a.descriptive[k,1] <- mean(d[,1])
a.descriptive[k,2] <- mean(d[,2])
a.descriptive[k,3] <- mean(d[,3])
a.descriptive[k,4] <- mean(d[,4])

d<-matrix(NA, nrow=1, ncol=4)
d[1,1]<-mean(na.omit(data$d1c1)); 
d[1,2]<-sd(na.omit(data$d1c1)); 
d[1,3]<-min(na.omit(data$d1c1)); 
d[1,4]<-max(na.omit(data$d1c1)) 
k <- 3
a.descriptive[k,1] <- mean(d[,1])
a.descriptive[k,2] <- mean(d[,2])
a.descriptive[k,3] <- mean(d[,3])
a.descriptive[k,4] <- mean(d[,4])

d<-matrix(NA, nrow=1, ncol=4)
d[1,1]<-mean(na.omit(data$d1c0)); 
d[1,2]<-sd(na.omit(data$d1c0)); 
d[1,3]<-min(na.omit(data$d1c0)); 
d[1,4]<-max(na.omit(data$d1c0))

k <- 4
a.descriptive[k,1] <- mean(d[,1])
a.descriptive[k,2] <- mean(d[,2])
a.descriptive[k,3] <- mean(d[,3])
a.descriptive[k,4] <- mean(d[,4])

d<-matrix(NA, nrow=1, ncol=4)
d[1,1]<-mean(na.omit(data$d0c1)); 
d[1,2]<-sd(na.omit(data$d0c1)); 
d[1,3]<-min(na.omit(data$d0c1)); 
d[1,4]<-max(na.omit(data$d0c1)) 

k <- 5
a.descriptive[k,1] <- mean(d[,1])
a.descriptive[k,2] <- mean(d[,2])
a.descriptive[k,3] <- mean(d[,3])
a.descriptive[k,4] <- mean(d[,4])

d<-matrix(NA, nrow=1, ncol=4)
d[1,1]<-mean(na.omit(data$d0c0)); 
d[1,2]<-sd(na.omit(data$d0c0)); 
d[1,3]<-min(na.omit(data$d0c0)); 
d[1,4]<-max(na.omit(data$d0c0)) 
k <- 6
a.descriptive[k,1] <- mean(d[,1])
a.descriptive[k,2] <- mean(d[,2])
a.descriptive[k,3] <- mean(d[,3])
a.descriptive[k,4] <- mean(d[,4])

d<-matrix(NA, nrow=1, ncol=4)
d[1,1]<-mean(na.omit(data$civtot)); 
d[1,2]<-sd(na.omit(data$civtot)); 
d[1,3]<-min(na.omit(data$civtot)); 
d[1,4]<-max(na.omit(data$civtot)) 
k <- 7
a.descriptive[k,1] <- mean(d[,1])
a.descriptive[k,2] <- mean(d[,2])
a.descriptive[k,3] <- mean(d[,3])
a.descriptive[k,4] <- mean(d[,4])

d<-matrix(NA, nrow=1, ncol=4)
d[1,1]<-mean(log(na.omit(data$populationvalues))); 
d[1,2]<-sd(log(na.omit(data$populationvalues))); 
d[1,3]<-min(log(na.omit(data$populationvalues))); 
d[1,4]<-max(log(na.omit(data$populationvalues))) 
k <- 8
a.descriptive[k,1] <- mean(d[,1])
a.descriptive[k,2] <- mean(d[,2])
a.descriptive[k,3] <- mean(d[,3])
a.descriptive[k,4] <- mean(d[,4])

d<-matrix(NA, nrow=1, ncol=4)
d[1,1]<-mean(log(na.omit(data$realpercapitaincomevalues))); 
d[1,2]<-sd(log(na.omit(data$realpercapitaincomevalues))); 
d[1,3]<-min(log(na.omit(data$realpercapitaincomevalues))); 
d[1,4]<-max(log(na.omit(data$realpercapitaincomevalues))) 
k <- 9
a.descriptive[k,1] <- mean(d[,1])
a.descriptive[k,2] <- mean(d[,2])
a.descriptive[k,3] <- mean(d[,3])
a.descriptive[k,4] <- mean(d[,4])

d<-matrix(NA, nrow=1, ncol=4)
d[1,1]<-mean(na.omit(data$treaty.rat.avg)); 
d[1,2]<-sd(na.omit(data$treaty.rat.avg)); 
d[1,3]<-min(na.omit(data$treaty.rat.avg)); 
d[1,4]<-max(na.omit(data$treaty.rat.avg) )
k <- 10
a.descriptive[k,1] <- mean(d[,1])
a.descriptive[k,2] <- mean(d[,2])
a.descriptive[k,3] <- mean(d[,3])
a.descriptive[k,4] <- mean(d[,4])

d<-matrix(NA, nrow=1, ncol=4)
d[1,1]<-mean(na.omit(data$democratization)); 
d[1,2]<-sd(na.omit(data$democratization)); 
d[1,3]<-min(na.omit(data$democratization)); 
d[1,4]<-max(na.omit(data$democratization)) 
k <- 11
a.descriptive[k,1] <- mean(d[,1])
a.descriptive[k,2] <- mean(d[,2])
a.descriptive[k,3] <- mean(d[,3])
a.descriptive[k,4] <- mean(d[,4])

d<-matrix(NA, nrow=1, ncol=4)
d[1,1]<-mean(log(na.omit(data$totalaid+1))); 
d[1,2]<-sd(log(na.omit(data$totalaid+1))); 
d[1,3]<-min(log(na.omit(data$totalaid+1))); 
d[1,4]<-max(log(na.omit(data$totalaid+1))) 
k <- 12
a.descriptive[k,1] <- mean(d[,1])
a.descriptive[k,2] <- mean(d[,2])
a.descriptive[k,3] <- mean(d[,3])
a.descriptive[k,4] <- mean(d[,4])

d<-matrix(NA, nrow=1, ncol=4)
d[1,1]<-mean(log(na.omit(data$trade+1))); 
d[1,2]<-sd(log(na.omit(data$trade+1))); 
d[1,3]<-min(log(na.omit(data$trade+1))); 
d[1,4]<-max(log(na.omit(data$trade+1))) 
k <- 13
a.descriptive[k,1] <- mean(d[,1])
a.descriptive[k,2] <- mean(d[,2])
a.descriptive[k,3] <- mean(d[,3])
a.descriptive[k,4] <- mean(d[,4])

dd <- data.frame(a.descriptive, row.names=c("Stable Democracy", "Court", "Stable Democracy and Court", "Stable Democracy and Not Court", "Not Stable Democracy and Court",  "Not Stable Democracy and Not Court", "Political Violence", "ln(Population)", "ln(Income)", "Treaty", "Democratization", "ln(Aid+1)", "ln(Trade+1)"))
names(dd)[1:4] <- c("Mean", "Std. Dev.", "Min", "Max")
dd


# to replicate the results found in Table 5,6,7,8,9,10,11 and 21
# use the Stata do file: DerogationReplication.do
# and the Stata data file: DerogationReplication.dta
# if you have questions about this file or the data please e-mail: cjf0006@gmail.com
